@@ -1,5 +1,5 @@
 package Pithub;
-$Pithub::VERSION = '0.01028';
+$Pithub::VERSION = '0.01029';
 our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 API
@@ -13,10 +13,35 @@ use Pithub::Orgs;
 use Pithub::PullRequests;
 use Pithub::Repos;
 use Pithub::Search;
+use Pithub::SearchV3;
 use Pithub::Users;
+use Carp 'croak';
 extends 'Pithub::Base';
 
 
+sub _validate_search_api {
+    my %search_apis = map { $_ => 1 } qw(legacy v3);
+    croak "unknown search api '$_[0]'"
+        unless exists $search_apis{$_[0]};
+}
+
+
+has search_api => (
+    is  => 'ro',
+    isa => \&_validate_search_api,
+    default => 'legacy',
+);
+
+sub _search_class {
+    my ($self, $search_api) = @_;
+
+    _validate_search_api($search_api);
+
+    return $search_api eq 'legacy'
+        ? 'Pithub::Search'
+        : 'Pithub::SearchV3';
+}
+
 
 sub events {
     return shift->_create_instance('Pithub::Events', @_);
@@ -54,7 +79,13 @@ sub repos {
 
 
 sub search {
-    return shift->_create_instance('Pithub::Search', @_);
+    my ($self, %args) = @_;
+    my $class = $self->_search_class(
+        exists $args{search_api}
+            ? delete $args{search_api}
+            : $self->search_api,
+    );
+    return shift->_create_instance($class, @_);
 }
 
 
@@ -77,7 +108,7 @@ Pithub - Github v3 API
 
 =head1 VERSION
 
-version 0.01028
+version 0.01029
 
 =head1 SYNOPSIS
 
@@ -98,6 +129,11 @@ version 0.01028
         printf "%s\n", $row->{name};
     }
 
+    # Connect to your local GitHub Enterprise instance
+    my $p = Pithub->new(
+        api_uri => 'https://github.yourdomain.com/api/v3/'
+    );
+
 =head1 DESCRIPTION
 
 L<Pithub> provides a set of modules to access the
@@ -106,6 +142,17 @@ oriented way. There is also L<Net::GitHub> which does the same for
 all the versions (v1, v2, v3) of the Github API.
 L<Pithub> supports all API calls so far, but only for v3.
 
+=head1 ATTRIBUTES
+
+=head2 search_api
+
+    my $p = Pithub->new({ search_api => 'v3' });
+    my $search = $p->search; # $search->isa('Pithub::SearchV3');
+
+This attribute allows the default for the API to use for searches to be
+specified. The two accepted values are C<v3> and C<legacy>. For compatibility
+reasons the default is C<legacy>.
+
 =head1 METHODS
 
 =head2 events
@@ -138,7 +185,13 @@ Provides access to L<Pithub::Repos>.
 
 =head2 search
 
-Provides access to L<Pithub::Search>.
+  my $legacy_search  = $p->search(search_api => 'legacy');
+  my $v3_search      = $p->search(search_api => 'v3');
+  my $default_search = $p->search;
+
+Provides access to L<Pithub::Search> and L<Pithub::SearchV3>. When no
+C<search_api> option is given, the value provided by the C<search_api>
+attribute is used.
 
 =head2 users
 
@@ -634,6 +687,10 @@ Andreas Marienborg
 
 Alessandro Ghedini
 
+=item *
+
+Michael G Schwern
+
 =back
 
 =head1 AUTHOR
