@@ -1,5 +1,5 @@
 package Pithub::Base;
-$Pithub::Base::VERSION = '0.01028';
+$Pithub::Base::VERSION = '0.01029';
 our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 base class for all Pithub modules
@@ -274,7 +274,7 @@ sub has_token {
 
     # If we have one specified in the object, return true
     return 1 if $self->_has_token;
-    # If no reqest object here, we don't have a token
+    # If no request object here, we don't have a token
     return 0  unless $request;
 
     return 1 if $request->header('Authorization');
@@ -404,7 +404,7 @@ Pithub::Base - Github v3 base class for all Pithub modules
 
 =head1 VERSION
 
-version 0.01028
+version 0.01029
 
 =head1 DESCRIPTION
 
@@ -469,7 +469,8 @@ See also: L<Pithub::Result/auto_pagination>.
 
 =head2 api_uri
 
-Defaults to L<https://api.github.com>.
+Defaults to L<https://api.github.com>.  For GitHub Enterprise, you'll likely
+need an URL like L<https://github.yourdomain.com/api/v3/>.
 
 Examples:
 
